from typing import Optional

from peek_platform import PeekPlatformConfig
from peek_plugin_base.client.PeekClientPlatformHookABC import PeekClientPlatformHookABC


class PeekClientPlatformHook(PeekClientPlatformHookABC):
    def getOtherPluginApi(self, pluginName: str) -> Optional[object]:
        pluginLoader = PeekPlatformConfig.pluginLoader

        otherPlugin = pluginLoader.pluginEntryHook(pluginName)
        if not otherPlugin:
            return None

        from peek_plugin_base.client.PluginClientEntryHookABC import \
            PluginClientEntryHookABC
        assert isinstance(otherPlugin, PluginClientEntryHookABC), (
            "Not an instance of PluginClientEntryHookABC")

        return otherPlugin.publishedClientApi



__author__ = 'peek'
__version__ = '0.2.13'

from txhttputil.util.ModuleUtil import filterModules

for mod in filterModules(__name__, __file__):
    __import__(mod, locals(), globals())


def importPackages():
    from . import backend
    from . import plugin
    from . import sw_install

